# Configuration & Dependencies

## 5.1 Extension Configuration

## 5.2 External Dependencies

- **Monoco CLI**
  - **Usage**: Core business logic execution (Lint, Update, Index).
  - **Requirement**: Must be accessible in system PATH.

- **Node.js Runtime**
  - **Usage**: Running Language Server.
